@@ -1,4 +1,4 @@
-# Copyright (C) 2009-2015  Lars Wirzenius
+# Copyright (C) 2009-2016  Lars Wirzenius
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 import cliapp
 
 
-from .version import __version__
+from .version import __version__, __version_info__
 from .structurederror import StructuredError
 from .structurederror_finder import find_structured_errors
 from .obnamerror import ObnamError
@@ -150,9 +150,22 @@ from .repo_interface import (
     REPO_FILE_DEV,
     REPO_FILE_INO,
     REPO_FILE_MD5,
+    REPO_FILE_SHA224,
+    REPO_FILE_SHA256,
+    REPO_FILE_SHA384,
+    REPO_FILE_SHA512,
     REPO_FILE_INTEGER_KEYS,
     metadata_file_key_mapping)
 
+from .checksummer import (
+    checksum_algorithms,
+    get_checksum_algorithm,
+    get_checksum_algorithm_name,
+    get_checksum_algorithm_key,
+)
+
+from .whole_file_checksummer import WholeFileCheckSummer
+
 from .delegator import RepositoryDelegator, GenerationId
 
 from .backup_progress import BackupProgress
@@ -163,6 +176,7 @@ from .backup_progress import BackupProgress
 #
 
 from .fmt_ga import (
+    GREEN_ALBATROSS_VERSION,
     RepositoryFormatGA,
     GAClientList,
     GAClient,
@@ -171,7 +185,12 @@ from .fmt_ga import (
     create_gadirectory_from_dict,
     GATree,
     GAChunkStore,
-    GAChunkIndexes)
+    GAChunkIndexes,
+    InMemoryLeafStore,
+    LeafStore,
+    CowLeaf,
+    CowTree,
+)
 
 
 #
