@@ -88,10 +88,24 @@ class App(cliapp.Application):
 
         self.settings.choice(
             ['repository-format'],
-            ['6', 'green-albatross'],
-            'use FORMAT for new repositories; one of "6", "green-albatross"',
+            ['6', obnamlib.GREEN_ALBATROSS_VERSION],
+            'use FORMAT for new repositories; '
+            'one of "6", "{}"'.format(obnamlib.GREEN_ALBATROSS_VERSION),
             metavar='FORMAT')
 
+        algos = list(obnamlib.checksum_algorithms)
+        algos.remove('sha512')  # We move this first in the list, default.
+        algos.remove('md5')  # We're NOT letting the user choose MD5.
+        algos = ['sha512'] + algos
+        self.settings.choice(
+            ['checksum-algorithm'],
+            algos,
+            'use CHECKSUM for checksum algorithm '
+            '(not for repository format 6); '
+            'one of: ' +
+            ', '.join(algos),
+            metavar='CHECKSUM')
+
         # Performance related settings.
 
         perf_group = obnamlib.option_group['perf']
@@ -260,6 +274,7 @@ class App(cliapp.Application):
             'chunk_bag_size': self.settings['chunk-bag-size'],
             'dir_cache_size': self.settings['dir-cache-size'],
             'dir_bag_size': self.settings['dir-bag-size'],
+            'checksum_algorithm': self.settings['checksum-algorithm'],
         }
 
         if create:
@@ -271,7 +286,7 @@ class App(cliapp.Application):
     def get_default_repository_class(self):
         classes = {
             '6': obnamlib.RepositoryFormat6,
-            'green-albatross': obnamlib.RepositoryFormatGA,
+            obnamlib.GREEN_ALBATROSS_VERSION: obnamlib.RepositoryFormatGA,
             }
         return classes[self.settings['repository-format']]
 
