@@ -1,4 +1,4 @@
-# Copyright 2015  Lars Wirzenius
+# Copyright 2015-2016  Lars Wirzenius
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -171,7 +171,16 @@ class RepositoryDelegator(obnamlib.RepositoryInterface):
 
     def _require_got_client_lock(self, client_name):
         if not self.got_client_lock(client_name):
-            raise obnamlib.RepositoryClientNotLocked()
+            raise obnamlib.RepositoryClientNotLocked(client_name=client_name)
+
+    def flush_client(self, client_name):
+        self._require_got_client_lock(client_name)
+        client = self._lookup_client(client_name)
+        client.flush()
+
+    def flush_ro_client(self, client_name):
+        client = self._lookup_client(client_name)
+        client.flush_ro()
 
     def commit_client(self, client_name):
         self._require_got_client_lock(client_name)
@@ -267,6 +276,10 @@ class RepositoryDelegator(obnamlib.RepositoryInterface):
         return client.set_file_keys_from_metadata(
             generation_id.gen_number, filename, metadata)
 
+    def get_client_checksum_key(self, client_name):
+        client = self._lookup_client(client_name)
+        return client.get_client_checksum_key()
+
     def get_file_chunk_ids(self, generation_id, filename):
         client = self._lookup_client_by_generation(generation_id)
         return client.get_file_chunk_ids(generation_id.gen_number, filename)
