@@ -851,7 +851,7 @@ class RepositoryFormat6(obnamlib.RepositoryInterface):
         # field names. This simplifies code (at the cost of a little
         # magic) in the file key getting and setting code.
         self._file_keys = {
-            obnamlib.REPO_FILE_TEST_KEY: 'target',
+            obnamlib.REPO_FILE_TEST_KEY: 'test',
             obnamlib.REPO_FILE_MODE: 'st_mode',
             obnamlib.REPO_FILE_MTIME_SEC: 'st_mtime_sec',
             obnamlib.REPO_FILE_MTIME_NSEC: 'st_mtime_nsec',
@@ -993,6 +993,9 @@ class RepositoryFormat6(obnamlib.RepositoryInterface):
                 client_name=client_name,
                 key_name=obnamlib.repo_key_name(key))
 
+    def get_client_checksum_key(self, client_name):
+        return obnamlib.REPO_FILE_MD5
+
     def get_file_chunk_ids(self, generation_id, filename):
         self._require_existing_file(generation_id, filename)
         client_name, gen_number = self._unpack_gen_id(generation_id)
