@@ -1,4 +1,4 @@
-# Copyright 2015  Lars Wirzenius
+# Copyright 2015-2016  Lars Wirzenius
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -25,11 +25,14 @@ import obnamlib
 
 class GAClient(object):
 
+    _well_known_blob = 'root'
+
     def __init__(self, client_name):
         self._fs = None
         self._dirname = None
         self._client_name = client_name
         self._current_time = None
+        self._default_checksum_algorithm = None
         self.clear()
 
     def clear(self):
@@ -39,6 +42,7 @@ class GAClient(object):
         self._data_is_loaded = False
         self._dir_cache_size = obnamlib.DEFAULT_DIR_CACHE_BYTES
         self._dir_bag_size = obnamlib.DEFAULT_DIR_BAG_BYTES
+        self._checksum_algorithm = None
 
     def set_current_time(self, current_time):
         self._current_time = current_time
@@ -46,6 +50,14 @@ class GAClient(object):
     def set_fs(self, fs):
         self._fs = fs
 
+    def set_default_checksum_algorithm(self, name):
+        self._default_checksum_algorithm = name
+
+    def get_client_checksum_key(self):
+        self._load_data()
+        assert self._checksum_algorithm is not None
+        return obnamlib.get_checksum_algorithm_key(self._checksum_algorithm)
+
     def set_dir_bag_size(self, size):
         self._dir_bag_size = size
         if self._blob_store:
@@ -62,6 +74,15 @@ class GAClient(object):
     def get_dirname(self):
         return self._dirname
 
+    def flush(self):
+        self._save_file_metadata()
+
+    def flush_ro(self):
+        for gen in self._generations:
+            metadata = gen.get_file_metadata()
+            metadata.flush_ro()
+            gen.set_root_object_id(metadata.get_root_object_id())
+
     def commit(self):
         self._load_data()
         self._finish_current_generation_if_any()
@@ -97,12 +118,13 @@ class GAClient(object):
 
     def _save_per_client_data(self):
         data = {
+            'whole-file-checksum': self._checksum_algorithm,
             'keys': self._client_keys.as_dict(),
             'generations': [g.as_dict() for g in self._generations],
         }
         blob = obnamlib.serialise_object(data)
-        filename = self._get_filename()
-        self._fs.overwrite_file(filename, blob)
+        blob_store = self._get_blob_store()
+        blob_store.put_well_known_blob(self._well_known_blob, blob)
 
     def _load_data(self):
         if not self._data_is_loaded:
@@ -112,19 +134,19 @@ class GAClient(object):
             self._data_is_loaded = True
 
     def _load_per_client_data(self):
-        filename = self._get_filename()
-        if self._fs.exists(filename):
-            blob = self._fs.cat(filename)
+        blob_store = self._get_blob_store()
+        blob = blob_store.get_well_known_blob(self._well_known_blob)
+        if blob is None:
+            self._checksum_algorithm = self._default_checksum_algorithm
+        else:
             data = obnamlib.deserialise_object(blob)
+            self._checksum_algorithm = data['whole-file-checksum']
             self._client_keys.set_from_dict(data['keys'])
             for gen_dict in data['generations']:
                 gen = GAGeneration()
                 gen.set_from_dict(gen_dict)
                 self._generations.append(gen)
 
-    def _get_filename(self):
-        return os.path.join(self.get_dirname(), 'data.dat')
-
     def _load_file_metadata(self):
         blob_store = self._get_blob_store()
         for gen in self._generations:
@@ -353,13 +375,14 @@ class GAClient(object):
 
     def get_generation_chunk_ids(self, gen_number):
         self._load_data()
-        chunk_ids = set()
         generation = self._lookup_generation_by_gen_number(gen_number)
         metadata = generation.get_file_metadata()
-        for filename in metadata:
-            file_chunk_ids = metadata.get_file_chunk_ids(filename)
-            chunk_ids = chunk_ids.union(set(file_chunk_ids))
-        return list(chunk_ids)
+        sets = [
+            set(metadata.get_file_chunk_ids(filename))
+            for filename in metadata
+        ]
+        union = set().union(*sets)
+        return list(union)
 
     def get_file_children(self, gen_number, filename):
         self._load_data()
@@ -492,6 +515,9 @@ class GAFileMetadata(object):
         assert len(self._added_files) == 0
         self._tree.flush()
 
+    def flush_ro(self):
+        self._tree.flush_ro()
+
     def __iter__(self):
         for filename in self._added_files:
             yield filename
@@ -605,13 +631,17 @@ class GAFileMetadata(object):
                 filename, obnamlib.REPO_FILE_MODE, file_metadata.st_mode)
             self._flush_added_file(filename)
 
-        dir_obj, basename = self._get_mutable_dir_obj(filename)
-        if not dir_obj:
+        dir_obj, _, basename = self._get_dir_obj(filename)
+        if dir_obj is None:
             return False
 
         for key, field in obnamlib.metadata_file_key_mapping:
             value = getattr(file_metadata, field)
-            dir_obj.set_file_key(basename, key, value)
+            old_value = dir_obj.get_file_key(basename, key)
+            if value != old_value:
+                if not dir_obj.is_mutable():
+                    dir_obj, basename = self._get_mutable_dir_obj(filename)
+                dir_obj.set_file_key(basename, key, value)
 
         return True
 
@@ -622,10 +652,13 @@ class GAFileMetadata(object):
                 self._flush_added_file(filename)
             return True
         else:
-            dir_obj, basename = self._get_mutable_dir_obj(filename)
-            if not dir_obj:
+            immutable, _, basename = self._get_dir_obj(filename)
+            if not immutable:
                 return False
-            dir_obj.set_file_key(basename, key, value)
+            old_value = immutable.get_file_key(basename, key)
+            if old_value != value:
+                mutable, basename2 = self._get_mutable_dir_obj(filename)
+                mutable.set_file_key(basename2, key, value)
         return True
 
     def _get_mutable_dir_obj(self, filename):
