@@ -1,4 +1,4 @@
-# Copyright 2015  Lars Wirzenius
+# Copyright 2015-2016  Lars Wirzenius
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,16 +19,23 @@
 import obnamlib
 
 
+GREEN_ALBATROSS_VERSION = 'green-albatross-20160813'
+
+
 class RepositoryFormatGA(obnamlib.RepositoryDelegator):
 
-    format = 'green-albatross'
+    format = GREEN_ALBATROSS_VERSION
 
     def __init__(self, **kwargs):
         obnamlib.RepositoryDelegator.__init__(self, **kwargs)
 
         self.set_client_list_object(obnamlib.GAClientList())
+        self.set_client_factory(self._client_factory)
+
         self.set_chunk_indexes_object(obnamlib.GAChunkIndexes())
-        self.set_client_factory(obnamlib.GAClient)
+        self._checksum_algorithm = kwargs['checksum_algorithm']
+        self._chunk_indexes.set_default_checksum_algorithm(
+            kwargs['checksum_algorithm'])
 
         chunk_store = obnamlib.GAChunkStore()
         if 'chunk_size' in kwargs:  # pragma: no cover
@@ -37,6 +44,11 @@ class RepositoryFormatGA(obnamlib.RepositoryDelegator):
             chunk_store.set_chunk_cache_size(kwargs['chunk_cache_size'])
         self.set_chunk_store_object(chunk_store)
 
+    def _client_factory(self, client_name):
+        client = obnamlib.GAClient(client_name)
+        client.set_default_checksum_algorithm(self._checksum_algorithm)
+        return client
+
     def init_repo(self):
         pass
 
@@ -85,23 +97,29 @@ class RepositoryFormatGA(obnamlib.RepositoryDelegator):
             ]
 
     def get_allowed_file_keys(self):
-        return [obnamlib.REPO_FILE_TEST_KEY,
-                obnamlib.REPO_FILE_MODE,
-                obnamlib.REPO_FILE_MTIME_SEC,
-                obnamlib.REPO_FILE_MTIME_NSEC,
-                obnamlib.REPO_FILE_ATIME_SEC,
-                obnamlib.REPO_FILE_ATIME_NSEC,
-                obnamlib.REPO_FILE_NLINK,
-                obnamlib.REPO_FILE_SIZE,
-                obnamlib.REPO_FILE_UID,
-                obnamlib.REPO_FILE_USERNAME,
-                obnamlib.REPO_FILE_GID,
-                obnamlib.REPO_FILE_GROUPNAME,
-                obnamlib.REPO_FILE_SYMLINK_TARGET,
-                obnamlib.REPO_FILE_XATTR_BLOB,
-                obnamlib.REPO_FILE_BLOCKS,
-                obnamlib.REPO_FILE_DEV,
-                obnamlib.REPO_FILE_INO]
+        return [
+            obnamlib.REPO_FILE_TEST_KEY,
+            obnamlib.REPO_FILE_MODE,
+            obnamlib.REPO_FILE_MTIME_SEC,
+            obnamlib.REPO_FILE_MTIME_NSEC,
+            obnamlib.REPO_FILE_ATIME_SEC,
+            obnamlib.REPO_FILE_ATIME_NSEC,
+            obnamlib.REPO_FILE_NLINK,
+            obnamlib.REPO_FILE_SIZE,
+            obnamlib.REPO_FILE_UID,
+            obnamlib.REPO_FILE_USERNAME,
+            obnamlib.REPO_FILE_GID,
+            obnamlib.REPO_FILE_GROUPNAME,
+            obnamlib.REPO_FILE_SYMLINK_TARGET,
+            obnamlib.REPO_FILE_XATTR_BLOB,
+            obnamlib.REPO_FILE_BLOCKS,
+            obnamlib.REPO_FILE_DEV,
+            obnamlib.REPO_FILE_INO,
+            obnamlib.REPO_FILE_SHA224,
+            obnamlib.REPO_FILE_SHA256,
+            obnamlib.REPO_FILE_SHA384,
+            obnamlib.REPO_FILE_SHA512,
+        ]
 
     def interpret_generation_spec(self, client_name, genspec):
         ids = self.get_client_generation_ids(client_name)
