@@ -15,7 +15,6 @@
 
 
 import errno
-import hashlib
 import logging
 import os
 import re
@@ -291,7 +290,7 @@ class BackupPlugin(obnamlib.ObnamPlugin):
         self.repo.commit_client(self.client_name)
         self.repo.unlock_client(self.client_name)
 
-        self.progress.what(prefix + ': commiting shared chunk indexes')
+        self.progress.what(prefix + ': committing shared chunk indexes')
         self.repo.commit_chunk_indexes()
 
         self.progress.what(prefix + ': removing unused chunks')
@@ -388,8 +387,15 @@ class BackupPlugin(obnamlib.ObnamPlugin):
 
         self.root_metadata = self.fs.lstat(absroot)
 
+        num_dirs = 0
+        # The following is a very approximate guess, but we have no
+        # way of being exact.
+        dir_entry_size = 1000
+        flush_threshold = obnamlib.DEFAULT_DIR_BAG_BYTES / dir_entry_size
+
         for pathname, metadata in self.find_files(absroot):
             logging.info('Backing up %s', pathname)
+
             if not self.pretend:
                 existed = self.repo.file_exists(self.new_generation, pathname)
             try:
@@ -407,9 +413,17 @@ class BackupPlugin(obnamlib.ObnamPlugin):
                 if e.errno in (errno.ENOSPC, errno.EPIPE):
                     raise
 
+            if metadata.isdir() and not self.pretend:
+                num_dirs += 1
+                if num_dirs >= flush_threshold:
+                    self.repo.flush_client(self.client_name)
+                    self.app.dump_memory_profile('after flushing client')
+                    num_dirs = 0
+
             if self.checkpoint_manager.time_for_checkpoint():
                 self.make_checkpoint()
                 self.progress.what(pathname)
+                num_dirs = 0
 
         self.backup_parents('.')
 
@@ -727,10 +741,8 @@ class BackupPlugin(obnamlib.ObnamPlugin):
         tracing.trace('opening file for reading')
         f = self.fs.open(filename, 'r')
 
-        if obnamlib.REPO_FILE_MD5 in self.repo.get_allowed_file_keys():
-            summer = hashlib.md5()
-        else:
-            summer = None
+        checksum_key = self.repo.get_client_checksum_key(self.client_name)
+        whole_file_summer = obnamlib.WholeFileCheckSummer(checksum_key)
 
         chunk_size = int(self.app.settings['chunk-size'])
         while True:
@@ -742,12 +754,11 @@ class BackupPlugin(obnamlib.ObnamPlugin):
                 break
             tracing.trace('got %d bytes of data' % len(data))
             self.progress.update_progress_with_scanned(len(data))
-            if summer:
-                summer.update(data)
             if not self.pretend:
                 chunk_id = self.backup_file_chunk(data)
                 self.repo.append_file_chunk_id(
                     self.new_generation, filename, chunk_id)
+                whole_file_summer.append_chunk(data, chunk_id)
             else:
                 self.progress.update_progress_with_upload(len(data))
 
@@ -762,8 +773,10 @@ class BackupPlugin(obnamlib.ObnamPlugin):
         self.app.dump_memory_profile('at end of file content backup for %s' %
                                      filename)
         tracing.trace('done backing up file contents')
-        if summer:
-            metadata.md5 = summer.digest()
+
+        for key, name in obnamlib.metadata_file_key_mapping:
+            if key == checksum_key:
+                setattr(metadata, name, whole_file_summer.get_checksum())
 
     def backup_file_chunk(self, data):
         '''Back up a chunk of data by putting it into the repository.'''
