@@ -1,4 +1,4 @@
-# Copyright (C) 2010-2015  Lars Wirzenius
+# Copyright (C) 2010-2016  Lars Wirzenius
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,6 +15,7 @@
 
 
 import datetime
+import logging
 
 import obnamlib
 
@@ -36,6 +37,10 @@ class ForgetPlugin(obnamlib.ObnamPlugin):
         self.app.settings.require('repository')
         self.app.settings.require('client-name')
 
+        if not args and not self.app.settings['keep']:
+            logging.info('forget: Nothing to forget, not doing anything')
+            return
+
         self.setup_progress_reporting()
 
         self.repo = self.app.get_repository_object()
