@@ -1,4 +1,4 @@
-# Copyright (C) 2009-2015  Lars Wirzenius
+# Copyright (C) 2009-2016  Lars Wirzenius
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -28,6 +28,11 @@ class WrongNumberOfGenerationSettingsError(obnamlib.ObnamError):
     msg = 'The restore command wants exactly one generation option'
 
 
+class NoToError(obnamlib.ObnamError):
+
+    msg = 'The restore command wants a target set with --to'
+
+
 class RestoreErrors(obnamlib.ObnamError):
 
     msg = '''There were errors when restoring
@@ -124,6 +129,9 @@ class RestorePlugin(obnamlib.ObnamPlugin):
         self.app.settings.require('generation')
         self.app.settings.require('to')
 
+        if not self.app.settings['to']:
+            raise NoToError()
+
         logging.debug(
             'restoring generation %s', self.app.settings['generation'])
         logging.debug('restoring to %s', self.app.settings['to'])
@@ -253,7 +261,7 @@ class RestorePlugin(obnamlib.ObnamPlugin):
             self.hardlinks.forget(metadata)
 
     def restore_symlink(self, gen, filename, metadata):
-        logging.debug('restoring symlink %s', filename)
+        logging.debug('restoring symlink %r -> %r', filename, metadata.target)
 
     def restore_first_link(self, gen, filename, metadata):
         if stat.S_ISREG(metadata.st_mode):
