@@ -56,8 +56,12 @@ REPO_FILE_GROUPNAME = _get_next_id()
 REPO_FILE_SYMLINK_TARGET = _get_next_id()
 REPO_FILE_XATTR_BLOB = _get_next_id()
 REPO_FILE_MD5 = _get_next_id()
+REPO_FILE_SHA224 = _get_next_id()
+REPO_FILE_SHA256 = _get_next_id()
+REPO_FILE_SHA384 = _get_next_id()
+REPO_FILE_SHA512 = _get_next_id()
 
-_MAX_STRING_KEY = REPO_FILE_MD5
+_MAX_STRING_KEY = REPO_FILE_SHA512
 
 REPO_GENERATION_STARTED = _get_next_id()
 REPO_GENERATION_ENDED = _get_next_id()
@@ -124,6 +128,10 @@ metadata_file_key_mapping = [
     (REPO_FILE_DEV, 'st_dev'),
     (REPO_FILE_INO, 'st_ino'),
     (REPO_FILE_MD5, 'md5'),
+    (REPO_FILE_SHA224, 'sha224'),
+    (REPO_FILE_SHA256, 'sha256'),
+    (REPO_FILE_SHA384, 'sha384'),
+    (REPO_FILE_SHA512, 'sha512'),
 ]
 
 
@@ -535,6 +543,26 @@ class RepositoryInterface(object):
         '''
         raise NotImplementedError()
 
+    def flush_client(self, client_name):
+        '''Flush cached data from client. This is not a commit.
+
+        This requires the client to be locked.
+
+        This is a NOP, unless the a specific repository format gives
+        it meaning.
+
+        '''
+
+    def flush_ro_client(self, client_name):
+        '''Flush cached read-only data from client.
+
+        This does not require the client to be locked.
+
+        This is a NOP, unless the a specific repository format gives
+        it meaning.
+
+        '''
+
     def commit_client(self, client_name):
         '''Commit changes to client and DO NOT unlock it.
 
@@ -571,6 +599,10 @@ class RepositoryInterface(object):
         '''Return list of allowed per-client keys for thist format.'''
         raise NotImplementedError()
 
+    def get_client_checksum_key(self, client_name):
+        '''Return file key for preferred checksum for client, or None.'''
+        raise NotImplementedError()
+
     def get_client_key(self, client_name, key):
         '''Return current value of a key for a given client.
 
@@ -764,13 +796,17 @@ class RepositoryInterface(object):
         '''
 
         allowed = set(self.get_allowed_file_keys())
+        used = set()
         for key, field in obnamlib.metadata_file_key_mapping:
             if key in allowed:
                 self.set_file_key(
                     generation_id, filename, key, getattr(metadata, field))
+                used.add(key)
+
+        for key in allowed.difference(used):
+            self.set_file_key(generation_id, filename, key, None)
 
     def get_file_chunk_ids(self, generation_id, filename):
-
         '''Get the list of chunk ids for a file.'''
         raise NotImplementedError()
 
@@ -1491,7 +1527,7 @@ class RepositoryInterfaceTests(unittest.TestCase):  # pragma: no cover
             self.repo.get_client_generation_ids('fooclient'),
             [new_id])
 
-    def test_returns_direcotry_name_for_extra_data(self):
+    def test_returns_directory_name_for_extra_data(self):
         self.setup_client()
         self.assertTrue(
             type(self.repo.get_client_extra_data_directory('fooclient')),
@@ -1893,43 +1929,60 @@ class RepositoryInterfaceTests(unittest.TestCase):  # pragma: no cover
             gen_id, '/foo/bar', obnamlib.REPO_FILE_TEST_KEY)
 
     def test_committing_client_remembers_set_file_keys(self):
+        # We use the symlink target for these tests, since the
+        # FILE_TEST_KEY mightn't get stored.
+
         gen_id = self.create_generation()
         self.repo.add_file(gen_id, '/foo/bar')
         self.repo.set_file_key(
             gen_id, '/foo/bar', obnamlib.REPO_FILE_MODE, stat.S_IFREG)
         self.repo.set_file_key(
-            gen_id, '/foo/bar', obnamlib.REPO_FILE_TEST_KEY, 'yoyo')
+            gen_id, '/foo/bar', obnamlib.REPO_FILE_SYMLINK_TARGET, 'yoyo')
         self.repo.commit_client('fooclient')
         self.repo.unlock_client('fooclient')
         value = self.repo.get_file_key(
-            gen_id, '/foo/bar', obnamlib.REPO_FILE_TEST_KEY)
+            gen_id, '/foo/bar', obnamlib.REPO_FILE_SYMLINK_TARGET)
         self.assertEqual(value, 'yoyo')
 
     def test_setting_file_key_does_not_affect_previous_generation(self):
+        # We use the symlink target for these tests, since the
+        # FILE_TEST_KEY mightn't get stored.
+
         gen_id = self.create_generation()
         self.repo.add_file(gen_id, '/foo/bar')
         self.repo.set_file_key(
             gen_id, '/foo/bar', obnamlib.REPO_FILE_MODE, stat.S_IFREG)
         self.repo.set_file_key(
-            gen_id, '/foo/bar', obnamlib.REPO_FILE_TEST_KEY, 'first')
+            gen_id, '/foo/bar', obnamlib.REPO_FILE_SYMLINK_TARGET, 'first')
         self.repo.commit_client('fooclient')
         self.repo.unlock_client('fooclient')
 
         self.repo.lock_client('fooclient')
         gen_id_2 = self.repo.create_generation('fooclient')
         self.repo.set_file_key(
-            gen_id_2, '/foo/bar', obnamlib.REPO_FILE_TEST_KEY, 'second')
+            gen_id_2, '/foo/bar', obnamlib.REPO_FILE_SYMLINK_TARGET, 'second')
         self.repo.commit_client('fooclient')
         self.repo.unlock_client('fooclient')
 
         value = self.repo.get_file_key(
-            gen_id, '/foo/bar', obnamlib.REPO_FILE_TEST_KEY)
+            gen_id, '/foo/bar', obnamlib.REPO_FILE_SYMLINK_TARGET)
         self.assertEqual(value, 'first')
 
         value_2 = self.repo.get_file_key(
-            gen_id_2, '/foo/bar', obnamlib.REPO_FILE_TEST_KEY)
+            gen_id_2, '/foo/bar', obnamlib.REPO_FILE_SYMLINK_TARGET)
         self.assertEqual(value_2, 'second')
 
+    def test_returns_an_acceptable_checksum_file_key_or_none(self):
+        self.setup_client()
+        self.assertTrue(
+            self.repo.get_client_checksum_key('fooclient') in
+            [None,
+             obnamlib.REPO_FILE_MD5,
+             obnamlib.REPO_FILE_SHA224,
+             obnamlib.REPO_FILE_SHA256,
+             obnamlib.REPO_FILE_SHA384,
+             obnamlib.REPO_FILE_SHA512])
+
     def test_new_file_has_no_chunk_ids(self):
         gen_id = self.create_generation()
         self.repo.add_file(gen_id, '/foo/bar')
