@@ -1,4 +1,4 @@
-# Copyright 2013-2015  Lars Wirzenius
+# Copyright 2013-2016  Lars Wirzenius
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -183,9 +183,8 @@ manifest()
 
 get_fingerprint()
 {
-    gpg --fingerprint "$1" |
-    sed -n '/^ *Key fingerprint = /s///p' |
-    sed 's/ *//g'
+    gpg --fingerprint --with-colons "$1" |
+        awk -F: '/^fpr:/ { print $10; exit }'
 }
 
 
